==> spring-cloud-contract-verifier-3.1.2-sources.jar: org/springframework/cloud/contract/verifier/util/JsonToJsonPathsConverter.java <==
package org.springframework.cloud.contract.verifier.util;
import java.lang.*;
import java.util.*;
import java.io.*;
import java.net.*;
import groovy.lang.*;
import groovy.util.*;

@groovy.util.logging.Commons() public class JsonToJsonPathsConverter
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
@java.lang.Deprecated() public JsonToJsonPathsConverter
(org.springframework.cloud.contract.verifier.config.ContractVerifierConfigProperties configProperties) {}
public JsonToJsonPathsConverter
(boolean assertJsonSize) {}
public JsonToJsonPathsConverter
() {
super ();
}
public static  java.lang.String convertJsonPathAndRegexToAJsonPath(org.springframework.cloud.contract.spec.internal.BodyMatcher bodyMatcher) { return (java.lang.String)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithTestsSideValues(java.lang.Object json, groovy.lang.Closure parsingClosure) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithTestsSideValues(java.lang.Object json) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithStubsSideValues(java.lang.Object json, groovy.lang.Closure parsingClosure) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithStubsSideValues(java.lang.Object json) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public static  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithStubsSideValuesAndNoArraySizeCheck(java.lang.Object json) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
protected  java.lang.Object traverseRecursively(java.lang.Class parentType, org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable key, java.lang.Object value, groovy.lang.Closure closure) { return (java.lang.Object)null;}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public static  java.lang.Object removeMatchingJsonPaths(java.lang.Object json, org.springframework.cloud.contract.spec.internal.BodyMatchers bodyMatchers) { return (java.lang.Object)null;}
public static  java.lang.Object readElement(java.lang.Object json, java.lang.String jsonPath) { return (java.lang.Object)null;}
public static  java.lang.String convertJsonPathAndRegexToAJsonPath(org.springframework.cloud.contract.spec.internal.BodyMatcher bodyMatcher, java.lang.Object body) { return (java.lang.String)null;}
@groovy.transform.CompileStatic() public static  java.lang.Object generatedValueIfNeeded(java.lang.Object value) { return (java.lang.Object)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithTestsSideValues(java.lang.Object json, java.util.function.Function parsingClosure, boolean includeEmptyCheck) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithTestsSideValues(java.lang.Object json, groovy.lang.Closure parsingClosure, boolean includeEmptyCheck) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithStubsSideValues(java.lang.Object json, groovy.lang.Closure parsingClosure, boolean includeEmptyCheck) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public static  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithStubsSideValuesAndNoArraySizeCheck(java.lang.Object json, groovy.lang.Closure parsingClosure) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
protected  java.lang.Object traverseRecursively(java.lang.Class parentType, org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable key, java.lang.Object value, groovy.lang.Closure closure, groovy.lang.Closure parsingClosure) { return (java.lang.Object)null;}
protected  org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable list(java.util.List convertedValue, java.lang.Object entrykey, org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable parentKey) { return (org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable)null;}
protected  org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable valueToAsserter(org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable key, java.lang.Object value) { return (org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable)null;}
}

==> spring-cloud-contract-verifier-4.0.3-sources.jar: org/springframework/cloud/contract/verifier/util/JsonToJsonPathsConverter.java <==
package org.springframework.cloud.contract.verifier.util;

@groovy.util.logging.Commons() public class JsonToJsonPathsConverter
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public JsonToJsonPathsConverter
(boolean assertJsonSize) {}
public JsonToJsonPathsConverter
() {
super ();
}
public static  java.lang.String convertJsonPathAndRegexToAJsonPath(org.springframework.cloud.contract.spec.internal.BodyMatcher bodyMatcher) { return (java.lang.String)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithTestsSideValues(java.lang.Object json, groovy.lang.Closure parsingClosure) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithTestsSideValues(java.lang.Object json) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithStubsSideValues(java.lang.Object json, groovy.lang.Closure parsingClosure) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithStubsSideValues(java.lang.Object json) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public static  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithStubsSideValuesAndNoArraySizeCheck(java.lang.Object json) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
protected  java.lang.Object traverseRecursively(java.lang.Class parentType, org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable key, java.lang.Object value, groovy.lang.Closure closure) { return (java.lang.Object)null;}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public static  java.lang.Object removeMatchingJsonPaths(java.lang.Object json, org.springframework.cloud.contract.spec.internal.BodyMatchers bodyMatchers) { return (java.lang.Object)null;}
public static  java.lang.Object readElement(java.lang.Object json, java.lang.String jsonPath) { return (java.lang.Object)null;}
public static  java.lang.String convertJsonPathAndRegexToAJsonPath(org.springframework.cloud.contract.spec.internal.BodyMatcher bodyMatcher, java.lang.Object body) { return (java.lang.String)null;}
@groovy.transform.CompileStatic() public static  java.lang.Object generatedValueIfNeeded(java.lang.Object value) { return (java.lang.Object)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithTestsSideValues(java.lang.Object json, java.util.function.Function parsingClosure, boolean includeEmptyCheck) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithTestsSideValues(java.lang.Object json, groovy.lang.Closure parsingClosure, boolean includeEmptyCheck) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithStubsSideValues(java.lang.Object json, groovy.lang.Closure parsingClosure, boolean includeEmptyCheck) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
public static  org.springframework.cloud.contract.verifier.util.JsonPaths transformToJsonPathWithStubsSideValuesAndNoArraySizeCheck(java.lang.Object json, groovy.lang.Closure parsingClosure) { return (org.springframework.cloud.contract.verifier.util.JsonPaths)null;}
protected  java.lang.Object traverseRecursively(java.lang.Class parentType, org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable key, java.lang.Object value, groovy.lang.Closure closure, groovy.lang.Closure parsingClosure) { return (java.lang.Object)null;}
protected  org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable list(java.util.List convertedValue, java.lang.Object entrykey, org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable parentKey) { return (org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable)null;}
protected  org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable valueToAsserter(org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable key, java.lang.Object value) { return (org.springframework.cloud.contract.verifier.util.MethodBufferingJsonVerifiable)null;}
public static  java.lang.invoke.MethodHandles.Lookup $getLookup() { return (java.lang.invoke.MethodHandles.Lookup)null;}
}
